/* testing TestRGF.java, Rony G. Flatscher, 2001-04-21

   purpose: this Rexx program demonstrates the usage of the Java class "TestRGF" and
            demonstrates the usage of the BSF-interface, especially getting and setting
            values of fields

   invoke:  enter the following command to inoke the Rexx program "UseTestRGF.rex":

                  "java com.ibm.bsf.Main -lang rexx -in UseTestRGF.rex"
            or
                  "java com.ibm.bsf.Main -in UseTestRGF.rex"

            if extension "rex" is defined in the text file "\com\ibm\bsf\Languages.properties",
            which allows for determining the needed engine by looking at the file extension
*/

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

type = "TestRGF"                -- Java class name

say "Registering bean ..."

.bsf~import("testrgf", type)    -- import the Java class
tr1=.testrgf~new                -- create an instance

say "invoke toString() ..."
say left("", 79, "-")
say tr1~toString
say left("", 79, "-")

say "This came from Rexx."
say

say "invoke dump() ..."
say left("", 79, "-")
tr1~dump
say left("", 79, "-")
say "This came from Java."
say

if1 = tr1~getInstField1         -- invoking the Java defined field access method
say "if1="if1

sf1 = tr1~getStatField1         -- invoking the Java defined field access method
say "sf1="sf1

say
say "Now invoking the class' access methods, changing thereby the field values..."
tr1~setStatField1("i", sf1*1000)-- invoking the Java defined field set method
tr1~setInstField1("i", if1*1000)-- invoking the Java defined field set method

say
say "Now invoking the 'dump' method of the class:"
say left("", 79, "-")
tr1~dump
say left("", 79, "-")
say "This came from Java."

say
say "Now reading public fields *directly* with 'getFieldValue':"
say
say "statField1 [" || tr1~bsf.getFieldValue('statField1') || "] (a public static field)"
say "instField1 [" || tr1~bsf.getFieldValue('instField1') || "] (a public instance field)"
say left("", 40, "=")

say
say "instField2 [" || tr1~bsf.getFieldValue('instField2') || "] (a public instance field)"
say "instField3 [" || tr1~bsf.getFieldValue('instField3') || "] (a public instance field)"
say left("", 40, "=")
say

say left("", 40, "=")
say "Now setting public fields *directly* with 'setFieldValue' ..."
say
say "...new value for instField1: [" || tr1~bsf.setFieldValue('instField1', 'i', 1111) || "] (a public instance field)"
say "   get value for instField1: [" || tr1~bsf.getFieldValue('instField1') || "]"
say
say "...new value for instField2: [" || tr1~bsf.setFieldValue('instField2', 'i', 2222) || "] (a public instance field)"
say "   get value for instField2: [" || tr1~bsf.getFieldValue('instField2') || "]"
say
say "...new value for statField1: [" || tr1~bsf.setFieldValue('statField1', 'i', 9876) || "] (a public static field)"
say "   get value for statField1: [" || tr1~bsf.getFieldValue('statField1') || "]"
say left("", 40, "=")
say
say "now using the newly developed function for public static fields: 'getStaticValue'"
say
say "the public static field named 'statField1' has the value:" "[" || .bsf~getStaticValue("TestRGF", "statField1") || "]"

::requires "BSF.cls"            -- get the Object Rexx interface class


